@@ -1,10 +1,11 @@
-from gracie_feeds_api import GracieBaseAPI
-
-
-class countriesController(GracieBaseAPI):
+class countriesController:
     """Countries Controller"""
 
     _controller_name = "countriesController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def list(self):
         """Return the list of countries"""
@@ -14,8 +15,8 @@ class countriesController(GracieBaseAPI):
         api = '/countries/list'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
         """Return a country by ID.
@@ -35,5 +36,5 @@ class countriesController(GracieBaseAPI):
         api = '/countries/retrieve'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
