@@ -1,10 +1,11 @@
-from gracie_feeds_api import GracieBaseAPI
-
-
-class engineAppInfoController(GracieBaseAPI):
+class engineAppInfoController:
     """Engine App Info Controller"""
 
     _controller_name = "engineAppInfoController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def retrieve(self):
         """Return EngineApp info."""
@@ -14,8 +15,8 @@ class engineAppInfoController(GracieBaseAPI):
         api = '/engine-app/retrieve'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def searchParameters(self):
         """Return info."""
@@ -25,8 +26,8 @@ class engineAppInfoController(GracieBaseAPI):
         api = '/engine-app/searchParameters'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def system(self):
         """Return info."""
@@ -36,5 +37,5 @@ class engineAppInfoController(GracieBaseAPI):
         api = '/engine-app/system'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
