@@ -1,10 +1,11 @@
-from gracie_feeds_api import GracieBaseAPI
-
-
-class invalidateController(GracieBaseAPI):
+class invalidateController:
     """Invalidate user's session forcefully."""
 
     _controller_name = "invalidateController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def invalidate(self, id):
         """Invalidate user's session forcefully.
@@ -24,5 +25,5 @@ class invalidateController(GracieBaseAPI):
         api = '/invalidate'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
