@@ -1,10 +1,11 @@
-from gracie_feeds_api import GracieBaseAPI
-
-
-class loginController(GracieBaseAPI):
+class loginController:
     """Login form."""
 
     _controller_name = "loginController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def login(self, login, password):
         """Login entry point.
@@ -25,5 +26,5 @@ class loginController(GracieBaseAPI):
         api = '/login'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
