@@ -1,10 +1,11 @@
-from gracie_feeds_api import GracieBaseAPI
-
-
-class typesController(GracieBaseAPI):
+class typesController:
     """Types Controller"""
 
     _controller_name = "typesController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def list(self, **kwargs):
         """Return the list of types.
@@ -24,8 +25,8 @@ class typesController(GracieBaseAPI):
         api = '/types/list'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
         """Return the type with specified ID.
@@ -45,5 +46,5 @@ class typesController(GracieBaseAPI):
         api = '/types/retrieve'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
